@@ -1,6 +1,8 @@
 var global_8h =
 [
-    [ "pw_bind_func_t", "global_8h.html#a18209e73d93da967908d5d66d86c42f2", null ],
+    [ "pw_global_events", "structpw__global__events.html", "structpw__global__events" ],
+    [ "PW_VERSION_GLOBAL_EVENTS", "global_8h.html#add2cfdc756b647e5f68c159a38473f40", null ],
+    [ "pw_global_add_listener", "global_8h.html#a48ade1ac8c560225b6d54dedbc48836a", null ],
     [ "pw_global_bind", "global_8h.html#ab3733783add50f8087bc6f551976798f", null ],
     [ "pw_global_destroy", "global_8h.html#a64e7b1922846aee0f5c9c6b16606506b", null ],
     [ "pw_global_get_core", "global_8h.html#ad4762f982a141fbed7a84f010c276bdf", null ],
@@ -12,6 +14,6 @@ var global_8h =
     [ "pw_global_get_properties", "global_8h.html#ac8b5326a91752657ed445c5d87010684", null ],
     [ "pw_global_get_type", "global_8h.html#a11272070f9f30cc8db783fbab453f9b3", null ],
     [ "pw_global_get_version", "global_8h.html#a3e5b2dd59d6cf7c614c3ed24b041a8b7", null ],
-    [ "pw_global_new", "global_8h.html#a268060d4c18c1c96d635b2e6cdafddf5", null ],
+    [ "pw_global_new", "global_8h.html#a8b2c5bd2858ec37b7a56cc7cfa2f79dd", null ],
     [ "pw_global_register", "global_8h.html#af0b886597338fe3e2e6d19717ac8b3fa", null ]
 ];
\ No newline at end of file
